@@ -9,7 +9,7 @@ use crate::imp::generate_root_source::generate_root_source;
 // RootIntfから取れたポインタは、RootIntfが削除されれば全て不正になる
 
 /// Generates Rust source code to access the root object
-pub fn generate_interface(root : &mut RootObject) -> RootSource{
+pub fn generate_interface(root : &RootObject) -> RootSource{
     let mem_descs = member_desc::get_member_desc(root);
     generate_root_source(&mem_descs)
 
