@@ -40,26 +40,20 @@ impl MListSource {
         let item_type_name = to_mitem_type_name(id);
         let fn_name = with_old(&snake_name, is_old);
         if self.undefiable{
-
             sb.push(0, &format!("pub fn {}(&self) -> Option<MListConst<{}>>{{", &fn_name , &item_type_name));
             sb.push(1, &format!("let mil = root::get_mlist_const(self.ptr, \"{}\").unwrap();", id));
             sb.push(1, &format!("mil.map(move |p| MListConst::new(p, self))"));
             sb.push(0, "}");
-            sb.push(0, &format!("pub fn {}_mut(&mut self) -> Option<MListMut<{}>>{{", &fn_name , &item_type_name));
-            sb.push(1, &format!("let mil = root::get_mlist_mut(self.ptr, \"{}\").unwrap();", id));
-            sb.push(1, &format!("mil.map(move |p| MListMut::new(p, self))"));
-            sb.push(0, "}");
         } else {
-
             sb.push(0, &format!("pub fn {}(&self) -> MListConst<{}>{{", &fn_name, &item_type_name));
             sb.push(1, &format!("let mil = root::get_mlist_const(self.ptr, \"{}\").unwrap().unwrap();", id));
             sb.push(1, &format!("MListConst::new(mil, self)"));
             sb.push(0, "}");
-            sb.push(0, &format!("pub fn {}_mut(&mut self) -> MListMut<{}>{{", &fn_name, &item_type_name));
-            sb.push(1, &format!("let mil = root::get_mlist_mut(self.ptr, \"{}\").unwrap().unwrap();", id));
-            sb.push(1, &format!("MListMut::new(mil, self)"));
-            sb.push(0, "}");
         }
+        sb.push(0, &format!("pub fn {}_mut(&mut self) -> MListMut<{}>{{", &fn_name, &item_type_name));
+        sb.push(1, &format!("let mil = root::get_mlist_mut(self.ptr, \"{}\").unwrap();", id));
+        sb.push(1, &format!("MListMut::new(mil, self)"));
+        sb.push(0, "}");
         sb.to_string()
     }
     pub fn to_string(&self) -> String{
